@@ -567,7 +567,7 @@ connect_unix_domain_socket_by_port(int port, char *socket_dir, bool retry)
 }
 
 /*
- * Connet to backend using pool_config->connect_timeout.
+ * Connect to backend using pool_config->connect_timeout.
  *
  * fd: the socket
  * walk: backend address to connect
@@ -676,7 +676,7 @@ connect_with_timeout(int fd, struct addrinfo *walk, char *host, int port, bool r
 				 * If read data or write data was set, either connect
 				 * succeeded or error.  We need to figure it out. This is the
 				 * hardest part in using non blocking connect(2).  See W.
-				 * Richar Stevens's "UNIX Network Programming: Volume 1,
+				 * Richard Stevens's "UNIX Network Programming: Volume 1,
 				 * Second Edition" section 15.4.
 				 */
 				if (FD_ISSET(fd, &rset) || FD_ISSET(fd, &wset))
@@ -978,6 +978,7 @@ static POOL_CONNECTION_POOL * new_connection(POOL_CONNECTION_POOL * p)
 		else
 		{
 			p->info[i].create_time = time(NULL);
+			p->info[i].client_idle_duration = 0;
 			p->slots[i] = s;
 
 			pool_init_params(&s->con->params);
@@ -1064,15 +1065,11 @@ close_all_backend_connections(void)
 
 	for (i = 0; i < pool_config->max_pool; i++, p++)
 	{
-		int	backend_id = in_use_backend_id(p);
-
-		if (backend_id < 0)
+		if (!MAIN_CONNECTION(p))
 			continue;
-		if (CONNECTION_SLOT(p, backend_id) == NULL)
+		if (!MAIN_CONNECTION(p)->sp)
 			continue;
-		if (CONNECTION_SLOT(p, backend_id)->sp == NULL)
-			continue;
-		if (CONNECTION_SLOT(p, backend_id)->sp->user == NULL)
+		if (MAIN_CONNECTION(p)->sp->user == NULL)
 			continue;
 		pool_send_frontend_exits(p);
 	}
